Skip to contents

For each island, plots a stacked bar showing the number of in-situ speciation, import, and export events as returned by decompose_diversity.

Usage

plot_diversity_decomposition(div)

Arguments

div

A data frame returned by decompose_diversity.

Value

Invisibly returns the matrix used for plotting.