Estimates the rate of in-situ speciation events per lineage per unit time
insitu_speciation_rate.RdFor each tip, counts the number of in-situ speciation events on the path
from the root to the tip and divides that by the total branch length of the
path. When the tree was prepared with prep_phylo and a
sampling_fraction less than 1 was set, branch lengths are scaled
upward by dividing by the sampling fraction before computing rates.
This approach corrects for the fact that incomplete sampling shortens
the total branch length of the observed tree relative to the true underlying tree.
Arguments
- phy
The matched phylogenetic tree prepared with
prep_phylo- events
The data frame returned by
map_insitu_events.